<?php
/**
 * Glamour magazine functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package glamour_magazine
 */

if ( ! function_exists( 'glamour_magazine_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function glamour_magazine_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on new blog, use a find and replace
		 * to change 'glamour-magazine' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'glamour-magazine');

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size('glamour-magazine-feature-display-thumbnail', 361, 175, array( 'center','top'));
		add_image_size('glamour-magazine-blog-display-thumbnail', 504, 350, array( 'center','top'));
		add_image_size('glamour-magazine-blog-1colume-thumbnail', 750, 350, array( 'center','top'));
		add_image_size('glamour-magazine-sidebar-latestpost-thumbnail', 90, 80, array( 'center','top'));

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'glamour-magazine' ),
		) );
		/**
		 * Configure for max number of Tag display
		 */
		add_filter('term_links-post_tag','glamour_magazine_limit_to_five_tags');
		function glamour_magazine_limit_to_five_tags($terms) {
		return array_slice($terms,0,5,true);
		}
		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'glamour_magazine_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 50,
			'width'       => 50,
			'flex-width' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'glamour_magazine_setup' );

/**
 * Change the excerpt more string
 */

function glamour_magazine_custom_excerpt_length( $length ) {
	if ( is_admin() ) {
		return $length;
	}
	return 42;
}
add_filter( 'excerpt_length', 'glamour_magazine_custom_excerpt_length', 999 );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function glamour_magazine_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'glamour_magazine_content_width', 640 );
}
add_action( 'after_setup_theme', 'glamour_magazine_content_width', 0 );

function glamour_magazine_comment($comment, $args, $depth) {
        $tag       = 'div';
        $add_below = 'comment';
   ?>
	<div class="media">
			<?php 
			if ( $args['avatar_size'] != 0 ) {
			?><div class="img-holder mr-4">
				<?php echo get_avatar( $comment, 100 ); ?>
			</div>
			<?php } ?>

			<div class="media-body">
				<div class="title-reply">
					<?php /* translators: %s: author */
					printf( __( '<cite class="fn mr-auto">%s</cite>','glamour-magazine' ), get_comment_author_link() ); ?>
					<span class="reply fa fa-reply" aria-hidden="true"><?php 
					comment_reply_link( 
						array_merge( 
							$args, 
							array( 
								'add_below' => $add_below, 
								'depth'     => $depth, 
								'max_depth' => $args['max_depth'],

							) 
						) 
					); ?>
					</span> 
				</div>

				<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ); ?>"><?php
				/* translators: 1: date, 2: time */
				printf( __('%1$s at %2$s','glamour-magazine'), get_comment_date(),  get_comment_time() ); ?>
				</a><?php 
				edit_comment_link( __( '(Edit)','glamour-magazine' ), '  ', '' ); ?>
				<br/>
				
				<?php comment_text(); ?>
			</div>
			<?php 
			if ( $comment->comment_approved == '0' ) { ?>
				<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.','glamour-magazine' ); ?></em><br/><?php 
			} ?>
			
	</div> 
	<br/>
	<br/>
	<?php
}

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function glamour_magazine_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'glamour-magazine' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'glamour-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s categories block">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class ="side-title" > <h4 class="widget-title "> <span>',
		'after_title'   => '</span></h4></div>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar one', 'glamour-magazine' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Add widgets here.', 'glamour-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s categories block">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class ="side-title" > <h4 class="widget-title "> <span>',
		'after_title'   => '</span></h4></div>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar two', 'glamour-magazine' ),
		'id'            => 'sidebar-3',
		'description'   => esc_html__( 'Add widgets here.', 'glamour-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s categories block">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class ="side-title" > <h4 class="widget-title "> <span>',
		'after_title'   => '</span></h4></div>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Side navbar', 'glamour-magazine' ),
		'id'            => 'sidebar-4',
		'description'   => esc_html__( 'Add widgets here.', 'glamour-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s categories block">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class ="side-title" > <h4 class="widget-title "> <span>',
		'after_title'   => '</span></h4></div>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Footer Sidebar three', 'glamour-magazine' ),
		'id'            => 'sidebar-5',
		'description'   => esc_html__( 'Add widgets here.', 'glamour-magazine' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s categories block">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class ="side-title" > <h4 class="widget-title "> <span>',
		'after_title'   => '</span></h4></div>',
	) );
}
add_action( 'widgets_init', 'glamour_magazine_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function glamour_magazine_scripts() {
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.css', array(), '4.1.1', 'all' );
	wp_enqueue_style( 'glamour-magazine-style', get_stylesheet_uri() );
	wp_enqueue_style( 'glamour-magazine-sidenav', get_template_directory_uri() . '/css/sidenav.css', array(), '1.0.0', 'all' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css', array(), '1.9.0', 'all' );
	wp_enqueue_style( 'wow', get_template_directory_uri() . '/css/animate.css', array(), '1.1.0', 'all' );
	wp_enqueue_style( 'google-webfonts', '//fonts.googleapis.com/css?family=Kaushan+Script|Poppins|Muli', array(), NULL);
	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/js/bootstrap.js', array('jquery'), '4.1.0', true );

	wp_enqueue_script( 'navigation', get_template_directory_uri() . '/js/navigation.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'jquery');
	wp_enqueue_script( 'smartmenu-js', get_template_directory_uri() . '/js/jquery.smartmenus.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'smartmenu-bootstrap-js', get_template_directory_uri() . '/js/jquery.smartmenus.bootstrap-4.js', array('jquery'), '20151215', true );
	wp_enqueue_script( 'wowscript', get_template_directory_uri() . '/js/wow.js', array('jquery'), '1.1.0', false );
	wp_enqueue_script( 'glamour-magazine-sidenav-js', get_template_directory_uri() . '/js/sidenav.js', array('jquery'), '20181201', true );
	wp_enqueue_script( 'glamour-magazine-js', get_template_directory_uri() . '/js/glamour-magazine.js', array('jquery'), '20181201', true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'glamour_magazine_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load walker.
 */

require get_template_directory() . '/inc/class-wp-bootsrtrap-navwalker.php';

/**
 *  load sanitize.
 */
require_once( trailingslashit( get_template_directory() ) . 'inc/sanitize.php' );

require get_template_directory() . '/inc/customizer/customizer-color.php';

/**
 * This function adds some styles to the WordPress Customizer
 */
function glamour_magazine_customizer_styles() { ?>
	<style>
		#customize-control-glamour_magazine_sidebar_enable,
		#customize-control-glamour_magazine_sidebar_about_enable,
		#customize-control-glamour_magazine_sidebar_post_enable,
		#customize-control-glamour_magazine_sidebar_quote_enable,
		#customize-control-glamour_magazine_single_page_author_title label,
		#customize-control-glamour_magazine_related_post_title label,
		#customize-control-glamour_magazine_sidebar_enable_page
		{
			border-bottom: 2px solid #000000;
			font-weight: 900;
		}
		
	</style>
	<?php

}
add_action( 'customize_controls_print_styles', 'glamour_magazine_customizer_styles', 999 );

function glamour_magazine_add_class_to_excerpt( $excerpt ) {
    return str_replace('<p', '<p class="text-justify conetentline"', $excerpt);
}
add_filter( "the_excerpt", "glamour_magazine_add_class_to_excerpt" );

function glamour_magazine_cat() {
	?><ul>
	<?php foreach(get_the_category() as $category)
	{
	echo '<a href="'.get_category_link($category->cat_ID).'"><li class="cat mr-2"> '.$category->cat_name.'</li></a>';
	}
	?>
	</ul>
	<?php
}

function glamour_magazine_modal() {
	if(absint(get_theme_mod('glamour_magazine_blog_post_post_taxonomy_'.'Read more','1'))==1): ?>
		<?php if(absint(get_theme_mod('glamour_magazine_popup_enable','1'))==1): ?>
			<a class=" btn <?php if ( esc_attr(get_theme_mod('glamour_magazine_blog_post_layout','2'))==1 ) {echo 'mt-4'; } else { echo 'float-left' ;} ?>" data-toggle="modal" data-target="#post-content-<?php the_ID(); ?>"><?php echo esc_html(get_theme_mod('glamour_magazine_read_more_title',__('Read More', 'glamour-magazine'))); ?></a>
			<!-- Modal -->
			<div class="modal fade" id="post-content-<?php the_ID(); ?>" role="dialog">
				<div class="modal-dialog modal-dialog-centered modal-dialog-scrollable modal-lg">
					<!-- Modal content-->
					<div class="modal-content">
						<div class="modal-header">
						<a class=" btn" href="<?php the_permalink(); ?>"><?php echo esc_html(get_theme_mod('glamour_magazine_detail_here_title',__('Full view here', 'glamour-magazine'))); ?></a>
						<button type="button" class="close" data-dismiss="modal">&times;</button>
						</div>
						<div class="modal-body text-justify">
							<?php the_content();?>
						</div>
						<div class="modal-footer">
						<button type="button" class="btn btn-default" data-dismiss="modal"><?php echo esc_html(get_theme_mod('glamour_magazine_close_title',__('Close', 'glamour-magazine'))); ?></button>
						</div>
					</div>
				</div>
			</div>
		<?php else : ?>
			<a class=" btn float-left" href="<?php the_permalink(); ?>"><?php echo esc_html(get_theme_mod('glamour_magazine_read_more_title',__('Read More', 'glamour-magazine'))); ?></a>
		<?php endif; 
	endif; 
}